===================================================
BTC Floating Windows
===================================================

Floating windows for use as pop-ups, modal or separate sources of information
in a user graphical interface.

Detailed documentation is in the "docs" directory.

Quick start
-----------

No description yet